[SCM] Multi-format 1D/2D barcode image processing library branch, upstream, updated. 24d4480bc48cf9eabf7b2bd2f528248b0e458809
srowen
srowen at 59b500cc-1b3d-0410-9834-0bbf25fbcc57
Wed Aug 4 01:32:06 UTC 2010
The following commit has been merged in the upstream branch:
commit 3099090045ff845693aaaa73fa3079365a6b801d
Author: srowen <srowen at 59b500cc-1b3d-0410-9834-0bbf25fbcc57>
Date: Tue Jun 15 21:53:48 2010 +0000
... and roll back a bit more to old status view, smaller text again
git-svn-id: http://zxing.googlecode.com/svn/trunk@1431 59b500cc-1b3d-0410-9834-0bbf25fbcc57
diff --git a/android/res/layout/capture.xml b/android/res/layout/capture.xml
index 2073812..dc5a533 100755
--- a/android/res/layout/capture.xml
+++ b/android/res/layout/capture.xml
@@ -179,13 +179,20 @@
</LinearLayout>
- <TextView android:id="@+id/status_view"
- android:layout_width="wrap_content"
- android:layout_height="wrap_content"
- android:layout_gravity="bottom|center_horizontal"
- android:text="@string/msg_default_status"
- android:background="@color/transparent"
- android:textColor="@color/status_text"
- android.textSize="14sp"/>
+ <LinearLayout android:layout_width="fill_parent"
+ android:layout_height="wrap_content"
+ android:orientation="horizontal"
+ android:background="@color/part_transparent"
+ android:layout_gravity="bottom"
+ android:gravity="center">
+
+ <TextView android:id="@+id/status_view"
+ android:layout_width="wrap_content"
+ android:layout_height="wrap_content"
+ android:text="@string/msg_default_status"
+ android:textColor="@color/status_text"
+ android:textSize="14sp"/>
+
+ </LinearLayout>
</FrameLayout>
diff --git a/android/res/values/colors.xml b/android/res/values/colors.xml
index 1872d5b..e190e18 100755
--- a/android/res/values/colors.xml
+++ b/android/res/values/colors.xml
@@ -36,6 +36,7 @@
<color name="status_view">#50000000</color>
<color name="status_text">#ffffffff</color>
<color name="transparent">#00000000</color>
+ <color name="part_transparent">#7f000000</color>
<color name="viewfinder_frame">#ff000000</color>
<color name="viewfinder_laser">#ffff0000</color>
<color name="viewfinder_mask">#60000000</color>
diff --git a/android/src/com/google/zxing/client/android/CaptureActivity.java b/android/src/com/google/zxing/client/android/CaptureActivity.java
index f719bbb..13323d3 100755
--- a/android/src/com/google/zxing/client/android/CaptureActivity.java
+++ b/android/src/com/google/zxing/client/android/CaptureActivity.java
@@ -17,7 +17,6 @@
package com.google.zxing.client.android;
import android.util.TypedValue;
-import android.widget.Toast;
import com.google.zxing.BarcodeFormat;
import com.google.zxing.Result;
import com.google.zxing.ResultPoint;
@@ -136,7 +135,7 @@ public final class CaptureActivity extends Activity implements SurfaceHolder.Cal
private CaptureActivityHandler handler;
private ViewfinderView viewfinderView;
- private View statusView;
+ private TextView statusView;
private View resultView;
private MediaPlayer mediaPlayer;
private Result lastResult;
@@ -182,7 +181,7 @@ public final class CaptureActivity extends Activity implements SurfaceHolder.Cal
CameraManager.init(getApplication());
viewfinderView = (ViewfinderView) findViewById(R.id.viewfinder_view);
resultView = findViewById(R.id.result_view);
- statusView = findViewById(R.id.status_view);
+ statusView = (TextView) findViewById(R.id.status_view);
handler = null;
lastResult = null;
hasSurface = false;
@@ -522,8 +521,8 @@ public final class CaptureActivity extends Activity implements SurfaceHolder.Cal
TextView contentsTextView = (TextView) findViewById(R.id.contents_text_view);
CharSequence displayContents = resultHandler.getDisplayContents();
contentsTextView.setText(displayContents);
- // Crudely scale betweeen 22 and 42 -- bigger font for shorter text
- int scaledSize = Math.max(22, 42 - displayContents.length() / 4);
+ // Crudely scale betweeen 22 and 36 -- bigger font for shorter text
+ int scaledSize = Math.max(22, 36 - displayContents.length() / 4);
contentsTextView.setTextSize(TypedValue.COMPLEX_UNIT_SP, scaledSize);
int buttonCount = resultHandler.getButtonCount();
@@ -554,7 +553,7 @@ public final class CaptureActivity extends Activity implements SurfaceHolder.Cal
// barcode was found (e.g. contact info) rather than the full contents, which they won't
// have time to read.
ResultHandler resultHandler = ResultHandlerFactory.makeResultHandler(this, rawResult);
- Toast.makeText(this, resultHandler.getDisplayTitle(), Toast.LENGTH_SHORT).show();
+ statusView.setText(getString(resultHandler.getDisplayTitle()));
if (copyToClipboard) {
ClipboardManager clipboard = (ClipboardManager) getSystemService(CLIPBOARD_SERVICE);
@@ -688,6 +687,7 @@ public final class CaptureActivity extends Activity implements SurfaceHolder.Cal
private void resetStatusView() {
resultView.setVisibility(View.GONE);
+ statusView.setText(R.string.msg_default_status);
statusView.setVisibility(View.VISIBLE);
viewfinderView.setVisibility(View.VISIBLE);
lastResult = null;
--
Multi-format 1D/2D barcode image processing library
More information about the Pkg-google-commits
mailing list